@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 5953 2013-04-19 14:14:49Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 5983 2013-05-11 13:16:53Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -236,6 +236,10 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.7/jquery.jqplot.min.css';
 	const JQUERYS_MOBILE_FILENAME	= 'jquery_mobile/jquery.mobile-1.3.0.min.js';					// JQuery Mobile
 	const JQUERYS_MOBILE_CSS		= 'jquery_mobile/jquery.mobile.structure-1.3.0.min.css';				// JQuery Mobile
 	
+	// ##### 外部ライブラリ #####
+	const LIB_GOOGLEMAPS			= 'googlemaps';
+	const GOOGLEMAPS_FILENAME		= 'http://maps.google.com/maps/api/js?sensor=true';
+	
 	/**
 	 * コンストラクタ
 	 */
@@ -390,7 +394,8 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.7/jquery.jqplot.min.css';
 		$libs[self::LIB_JQUERYS] 			= array(	'script' => array(self::getJQueryFilename(10)));		// スマートフォン用jQuery
 		$libs[self::LIB_JQUERYS_MOBILE]		= array(	'script' 	=> array(self::JQUERYS_MOBILE_FILENAME),	// JQuery Mobile
 														'css'		=> array(self::JQUERYS_MOBILE_CSS));
-														
+		// 外部ライブラリ
+		$libs[self::LIB_GOOGLEMAPS]			= array(	'script'	=> array(self::GOOGLEMAPS_FILENAME));
 		return $libs;
 	}
 	/**
@@ -471,5 +476,17 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.7/jquery.jqplot.min.css';
 				return self::LIB_CKEDITOR;
 		}
 	}
+	/**
+	 * スクリプトを取得
+	 *
+	 * @param string $libId			ライブラリID
+	 * @return string				スクリプトファイル名またはURL
+	 */
+	static function getScript($libId)
+	{
+		$scripts = self::getLib()[$libId]['script'];
+		if (is_array($scripts) && count($scripts) == 1) $scripts = $scripts[0];
+		return $scripts;
+	}
 }
 ?>
