@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: analyticsDb.php 4165 2011-06-02 11:36:17Z fishbone $
+ * @version    SVN: $Id: analyticsDb.php 4908 2012-05-17 12:44:08Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/baseDb.php');
@@ -429,5 +429,45 @@ class analyticsDb extends BaseDb
 		$destStr = substr($str, 0, $len) . $addStr;
 		return $destStr;
 	}
+	/**
+	 * アクセスログにアクセス管理用クッキー値が存在しているかどうか
+	 *
+	 * @param string $cookieValue	クッキー値
+	 * @param int $serialNo			制限用シリアルNo(負の場合は制限なし)
+	 * @return						true=存在する、false=存在しない
+	 */
+	function isExistsCookieValueInAccessLog($cookieValue, $serialNo = -1)
+	{
+		$params = array();
+		$queryStr  = 'SELECT * FROM _access_log ';
+		$queryStr .=   'WHERE al_cookie_value = ? '; $params[] = $cookieValue;
+		if ($serialNo >= 0) $queryStr .=   'AND al_serial < ? '; $params[] = $serialNo;	// シリアルNoで制限
+		return $this->isRecordExists($queryStr, $params);
+	}
+	/**
+	 * アクセスログのアクセス解析値を更新
+	 *
+	 * @param int   $serialNo		ログシリアルNo
+	 * @param bool  $isFirst		最初のアクセスかどうか
+	 * @param bool  $isCrawler		クローラーかどうか
+	 * @return bool					true=更新成功、false=更新失敗
+	 */
+	function updateAccessLog($serialNo, $isFirst, $isCrawler)
+	{
+		// トランザクション開始
+		$this->startTransaction();
+		
+		$queryStr  = 'UPDATE _access_log ';
+		$queryStr .=   'SET ';
+		$queryStr .=     'al_analyzed = true, ';	// アクセス解析終了
+		$queryStr .=     'al_is_first = ?, ';
+		$queryStr .=     'al_crawler = ? ';
+		$queryStr .=   'WHERE al_serial = ?';
+		$params = array(intval($isFirst), intval($isCrawler), $serialNo);
+		$this->execStatement($queryStr, $params);
+			
+		// トランザクション終了
+		return $this->endTransaction();
+	}
 }
 ?>
