@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 5724 2013-02-24 23:17:22Z fishbone $
+ * @version    SVN: $Id: envManager.php 5779 2013-03-04 01:17:14Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/version.php');	// システムバージョンクラス
@@ -183,6 +183,8 @@ class EnvManager extends Core
 			if (function_exists('mb_language')) mb_language("Japanese");
 			if (function_exists('mb_internal_encoding')) mb_internal_encoding("UTF-8");
 		}
+		// 現在のルートURL初期化。外部アクセスのときはこのURLを使用。
+		$this->currentDomainRootUrl = M3_SYSTEM_ROOT_URL;
 	}
 	/**
 	 * システム関係のパラメータを再取得
@@ -222,7 +224,6 @@ class EnvManager extends Core
 	public function initMultiDomain()
 	{
 		// マルチドメイン運用の場合はルートURLを設定
-		$this->currentDomainRootUrl = M3_SYSTEM_ROOT_URL;	// マルチドメイン運用時の現在のルートURL
 		if ($this->multiDomain){
 			$url = '';
 			if ($this->isSmartphoneSite){
@@ -600,9 +601,10 @@ class EnvManager extends Core
 	 * システムの携帯用デフォルトindexのURLを取得
 	 *
 	 * @param bool $withMobileParam		携帯用のパラメータを付加するかどうか
+	 * @param bool $withFilename		ファイル名を付加するかどうか
 	 * @return string					携帯用デフォルトURL
 	 */
-	public function getDefaultMobileUrl($withMobileParam=false)
+	public function getDefaultMobileUrl($withMobileParam = false, $withFilename = true)
 	{
 		static $mobileUrl;
 		
@@ -610,13 +612,14 @@ class EnvManager extends Core
 			if (!isset($mobileUrl)) $mobileUrl = $this->gSystem->getSystemConfig(self::CF_SITE_MOBILE_URL);		// 携帯用サイトURL
 
 			if (empty($mobileUrl)){
-				$url = M3_SYSTEM_ROOT_URL . '/' . M3_DIR_NAME_MOBILE . '/' . M3_FILENAME_INDEX;
+				$url = M3_SYSTEM_ROOT_URL . '/' . M3_DIR_NAME_MOBILE;
 			} else {
-				$url = $mobileUrl . '/' . M3_FILENAME_INDEX;
+				$url = $mobileUrl;
 			}
 		} else {
-			$url = M3_SYSTEM_ROOT_URL . '/' . M3_DIR_NAME_MOBILE . '/' . M3_FILENAME_INDEX;
+			$url = M3_SYSTEM_ROOT_URL . '/' . M3_DIR_NAME_MOBILE;
 		}
+		if ($withFilename) $url .= '/' . M3_FILENAME_INDEX;
 		if ($withMobileParam){		// 携帯用のパラメータを付加するとき
 			$url = createUrl($url, $this->_getMobileUrlParam());
 		}
@@ -625,9 +628,10 @@ class EnvManager extends Core
 	/**
 	 * システムのスマートフォン用デフォルトindexのURLを取得
 	 *
+	 * @param bool $withFilename		ファイル名を付加するかどうか
 	 * @return string					スマートフォン用デフォルトURL
 	 */
-	public function getDefaultSmartphoneUrl()
+	public function getDefaultSmartphoneUrl($withFilename = true)
 	{
 		static $smartphoneUrl;
 		
@@ -635,13 +639,14 @@ class EnvManager extends Core
 			if (!isset($smartphoneUrl)) $smartphoneUrl = $url = $this->gSystem->getSystemConfig(self::CF_SITE_SMARTPHONE_URL);	// スマートフォン用サイトURL
 			
 			if (empty($smartphoneUrl)){
-				$url = M3_SYSTEM_ROOT_URL . '/' . M3_DIR_NAME_SMARTPHONE . '/' . M3_FILENAME_INDEX;
+				$url = M3_SYSTEM_ROOT_URL . '/' . M3_DIR_NAME_SMARTPHONE;
 			} else {
-				$url = $smartphoneUrl . '/' . M3_FILENAME_INDEX;
+				$url = $smartphoneUrl;
 			}
 		} else {
-			$url = M3_SYSTEM_ROOT_URL . '/' . M3_DIR_NAME_SMARTPHONE . '/' . M3_FILENAME_INDEX;
+			$url = M3_SYSTEM_ROOT_URL . '/' . M3_DIR_NAME_SMARTPHONE;
 		}
+		if ($withFilename) $url .= '/' . M3_FILENAME_INDEX;
 		return $url;
 	}
 	/**
