@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2012 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: _develop.sql 5857 2013-03-24 23:24:31Z fishbone $
+-- * @version    SVN: $Id: _develop.sql 6023 2013-05-20 04:28:34Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- [開発ウィジェット登録]   *****仕様変更あり注意*****
@@ -126,3 +126,59 @@ INSERT INTO _nav_item
 (502,   500,          1,        'admin_menu', 'configwidget_photo_shop',       '',             0,               'task=product', '商品管理', '商品管理', '商品管理を行います。', true),
 (503,   500,          2,        'admin_menu', 'configwidget_photo_shop',       '',             0,               'task=member',   '会員管理', '会員管理', '会員情報を管理します。', true);
 
+
+
+DELETE FROM _widgets WHERE wd_id = 'comment';
+INSERT INTO _widgets
+(wd_id,     wd_name,       wd_type, wd_content_type, wd_edit_content, wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib, wd_add_script_lib_a, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_initialized, wd_release_dt, wd_install_dt, wd_create_dt) VALUES
+('comment', '汎用コメント', '', 'comment', true, '1.0.0',    'Naoki Hirata', 'Magic3.org', 'GPL',      10,                'メインコンテンツウィジェットに付加する汎用のコメント機能', '',                '',                  true, false,         false,                true,  '2013-05-14', now(),         now());
+
+-- 汎用コメント設定マスター
+DROP TABLE IF EXISTS comment_config;
+CREATE TABLE comment_config (
+    cf_content_type      VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- コンテンツ種別
+    cf_content_id        VARCHAR(32)    DEFAULT ''                    NOT NULL,      -- コンテンツID(空の場合は共通)
+    
+    cf_type              INT            DEFAULT 0                     NOT NULL,      -- コメントタイプ(0=フラット,1=ツリー)
+    cf_view_direction    INT            DEFAULT 0                     NOT NULL,      -- 表示方向(0=昇順、1=降順)
+    cf_max_count         INT            DEFAULT 0                     NOT NULL,      -- コメント最大数
+    cf_max_length        INT            DEFAULT 0                     NOT NULL,      -- コメント文字数
+    cf_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示可否(個別設定可)
+    cf_visible_default   BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示可否デフォルト値
+    cf_start_dt          TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 使用期間(開始)(個別設定可)
+    cf_end_dt            TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 使用期間(終了)(個別設定可)
+    cf_user_limited      BOOLEAN        DEFAULT false                 NOT NULL,      -- 投稿ユーザを制限
+    cf_permit_html       BOOLEAN        DEFAULT false                 NOT NULL,      -- HTMLメッセージ
+    cf_permit_image      BOOLEAN        DEFAULT false                 NOT NULL,      -- 画像あり
+    cf_use_thumbnail     BOOLEAN        DEFAULT false                 NOT NULL,      -- サムネールあり
+    PRIMARY KEY          (cf_content_type,   cf_content_id)
+) TYPE=innodb;
+
+-- 汎用コメントトラン
+DROP TABLE IF EXISTS comment;
+CREATE TABLE comment (
+    cm_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    cm_content_type      VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- コンテンツ種別
+    cm_content_id        VARCHAR(32)    DEFAULT ''                    NOT NULL,      -- コンテンツID
+    cm_device_type       INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)
+    cm_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    cm_parent_serial     INT            DEFAULT 0                     NOT NULL,      -- 親コメントのシリアル番号
+    cm_user_id           INT            DEFAULT 0                     NOT NULL,      -- ユーザID
+    cm_regist_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 投稿日時
+    
+    cm_no                INT            DEFAULT 0                     NOT NULL,      -- コメント番号(投稿順)
+    cm_sort_order        INT            DEFAULT 0                     NOT NULL,      -- 表示順
+    cm_nest_level        INT            DEFAULT 0                     NOT NULL,      -- ツリータイプの場合のネスト段階
+    cm_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- タイトル
+    cm_message           TEXT                                         NOT NULL,      -- メッセージ
+    cm_url               TEXT                                         NOT NULL,      -- 参照用URL
+    cm_user_name         VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ユーザ名
+    cm_email             VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- Eメールアドレス
+    cm_status            SMALLINT       DEFAULT 0                     NOT NULL,      -- 状態(0=未設定、1=非公開、2=公開)
+    
+    cm_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    cm_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    cm_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (cm_serial)
+) TYPE=innodb;
+
