@@ -9,7 +9,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: main.js 5992 2013-05-13 12:50:27Z fishbone $
+ * @version    SVN: $Id: main.js 6020 2013-05-20 01:01:51Z fishbone $
  * @link       http://www.magic3.org
  */
 
@@ -53,8 +53,8 @@
 			dialog.setValueOf('tab_map', 'cmbZoom', mapInfo.zoom);
 			dialog.setValueOf('tab_map', 'txtCenterLat', mapInfo.centerLat);
 			dialog.setValueOf('tab_map', 'txtCenterLon', mapInfo.centerLon);
-			dialog.setValueOf('tab_line', 'txtEncodedPolyline', mapInfo.linePoints);
-			dialog.setValueOf('tab_line', 'txtEncodedLevels', mapInfo.lineLevels);
+//			dialog.setValueOf('tab_line', 'txtEncodedPolyline', mapInfo.linePoints);
+//			dialog.setValueOf('tab_line', 'txtEncodedLevels', mapInfo.lineLevels);
 			
 			// マップ作成
 			setPreviewElement(mapInfo.mapType);
@@ -73,10 +73,10 @@
 		};
 		var setPreviewElement = function(mapType)
 		{
-			mapDiv = document.getElementById("gmapPreview");
+			mapDiv = document.getElementById("gmapPreview" + editor.id);
 			resizeMap();
 	
-			allMapTypes = [	google.maps.MapTypeId.ROADMAP,
+			var allMapTypes = [	google.maps.MapTypeId.ROADMAP,
 							google.maps.MapTypeId.SATELLITE,
 							google.maps.MapTypeId.HYBRID,
 							google.maps.MapTypeId.TERRAIN	];
@@ -106,8 +106,8 @@
 						if (mode == 'AddMarker') addMarkerAtPoint(point, editor.lang.googlemaps.markerDefaultText || '', true);
 						break;
 					case 'tab_line':
-						createPoint(point.lat(), point.lng(), 3);
-						createEncodings(false);
+						polyline.createPoint(point.lat(), point.lng(), 3);
+						polyline.createEncodings(false);
 					break;
 				}
 				//mapDiv.focus();
@@ -124,7 +124,7 @@
 						case 'tab_marker':
 							break;
 						case 'tab_line':
-							deletePoint();
+							polyline.deletePoint();
 							break;
 					}
 				}
@@ -180,8 +180,8 @@
 				finishAddMarker();
 				return;
 			}
-			$('#btnAddNewMarker').attr('src', pluginUrl + 'images/AddMarkerDown.png');
-			$('#msgMarkerInstruction').text(editor.lang.googlemaps.msgMarkerInstruction);
+			$('#btnAddNewMarker' + editor.id).attr('src', pluginUrl + 'images/AddMarkerDown.png');
+			$('#msgMarkerInstruction' + editor.id).text(editor.lang.googlemaps.msgMarkerInstruction);
 			mode = 'AddMarker';
 			mapObj.setOptions({ draggableCursor:'crosshair' });
 		}
@@ -206,8 +206,8 @@
 		{
 			mode = '';
 			
-			$('#btnAddNewMarker').attr('src', pluginUrl + 'images/AddMarker.png');
-			$('#msgMarkerInstruction').text('');
+			$('#btnAddNewMarker' + editor.id).attr('src', pluginUrl + 'images/AddMarker.png');
+			$('#msgMarkerInstruction' + editor.id).text('');
 			mapObj.setOptions({ draggableCursor:'default' });
 		};
 		var editMarker = function(marker)
@@ -247,7 +247,7 @@
 		};
 		var updateCurrentMarker = function ()
 		{
-			if (activeMarker) activeMarker.setTitle($('#txtMarkerText').val().replace(/\n/g, '<br>'));
+			if (activeMarker) activeMarker.setTitle($('#txtMarkerText' + editor.id).val().replace(/\n/g, '<br>'));
 			closeInfoWindow();
 		};
 		var deleteCurrentMarker = function()
@@ -265,8 +265,8 @@
 		};
 		var generateEditPopupString = function(text)
 		{
-			return '<div><label for="txtMarkerText">' + editor.lang.googlemaps.markerText + '</label></div>' +
-				'<div><textarea id="txtMarkerText" class="cke_dialog_ui_input_textarea" style="width:300px; height:120px;">' + text.replace(/<br>/g, '\n') + '</textarea></div>' +
+			return '<div><label for="txtMarkerText' + editor.id + '">' + editor.lang.googlemaps.markerText + '</label></div>' +
+				'<div><textarea id="txtMarkerText' + editor.id + '" class="cke_dialog_ui_input_textarea" style="width:300px; height:120px;">' + text.replace(/<br>/g, '\n') + '</textarea></div>' +
 				'<div class="cke_dialog_footer_buttons"><div style="width:50%;display:inline-block;float:left;"><div class="cke_dialog_ui_hbox_child" style="display:inline-block;"><a id="btnDeleteMarker" class="cke_dialog_ui_button"><span class="cke_dialog_ui_button">' + editor.lang.googlemaps.deleteMarker + '</span></a></div></div>' +
 				'<div style="width:40%;display:inline-block;float:right;"><div class="cke_dialog_ui_hbox_first" style="display:inline-block;"><a id="btnOk" class="cke_dialog_ui_button cke_dialog_ui_button_ok"><span class="cke_dialog_ui_button">' + editor.lang.common.ok + '</span></a></div><div class="cke_dialog_ui_hbox_last" style="display:inline-block;">' +
 				'<a id="btnCancel" class="cke_dialog_ui_button cke_dialog_ui_button_cancel"><span class="cke_dialog_ui_button">' + editor.lang.common.cancel + '</span></a></div></div></div>';
@@ -299,16 +299,16 @@
 				dialog.on('selectPage', function(e){
 					switch (e.data.page){
 					case 'tab_map':
-						$('#gmapPreview').appendTo('#placeholder_map');
+						$('#gmapPreview' + editor.id).appendTo('#placeholder_map' + editor.id);
 						break;
 					case 'tab_search':
-						$('#gmapPreview').appendTo('#placeholder_search');
+						$('#gmapPreview' + editor.id).appendTo('#placeholder_search' + editor.id);
 						break;
 					case 'tab_marker':
-						$('#gmapPreview').appendTo('#placeholder_marker');
+						$('#gmapPreview' + editor.id).appendTo('#placeholder_marker' + editor.id);
 						break;
 					case 'tab_line':
-						$('#gmapPreview').appendTo('#placeholder_line');
+						$('#gmapPreview' + editor.id).appendTo('#placeholder_line' + editor.id);
 						break;
 					}
 
@@ -321,13 +321,13 @@
 					if (e.data.page != 'tab_marker') finishAddMarker();
 				});
 				// イベント登録
-				$('#btnAddNewMarker').click(function(){
+				$('#btnAddNewMarker' + editor.id).click(function(){
 					addMarker();
 				}).attr({ title:editor.lang.googlemaps.addMarker, alt:editor.lang.googlemaps.addMarker });
 			},
-			onFocus: function() {
+	/*		onFocus: function() {
 				mapDiv.focus();
-			},
+			},*/
 			onShow: function(){
 				// マップ初期化
 				markers = [];
@@ -364,6 +364,8 @@
 				mapInfo.markerPoints = markerPoints;
 				
 				// マップ埋め込みタグの作成
+				mapInfo.linePoints = polyline.encodedPolyline;
+				mapInfo.lineLevels = polyline.encodedLevels;
 				var script = mapInfo.buildScript();
 //				var scriptElement = CKEDITOR.dom.element.createFromHtml(script, editor.document);
 //				var newMapElement = CKEDITOR.dom.element.createFromHtml('<div></div>', editor.document);
@@ -516,7 +518,7 @@
 					} ]
 				}, {
 					type: 'html',
-					html: '<div id="placeholder_map"><div id="gmapPreview" style="outline:0;" tabIndex="-1"></div></div>'
+					html: '<div id="placeholder_map' + editor.id + '"><div id="gmapPreview' + editor.id + '" style="outline:0;" tabIndex="-1"></div></div>'
 				} ]		// elements
 			}, {
 				id: 'tab_search',
@@ -547,7 +549,7 @@
 					} ]
 				}, {
 					type: 'html',
-					html: '<div id="placeholder_search"></div>'
+					html: '<div id="placeholder_search' + editor.id + '"></div>'
 				} ]
 			}, {
 				id: 'tab_marker',
@@ -555,10 +557,10 @@
 				elements: [
 				{
 					type: 'html',
-html: '<img id="btnAddNewMarker" src="' + pluginUrl + 'images/AddMarker.png" style="cursor:pointer;" /><div id="msgMarkerInstruction" style="display:inline-block;"></div>'
+html: '<img id="btnAddNewMarker' + editor.id + '" src="' + pluginUrl + 'images/AddMarker.png" style="cursor:pointer;" /><div id="msgMarkerInstruction' + editor.id + '" style="display:inline-block;"></div>'
 				}, {
 					type: 'html',
-					html: '<div id="placeholder_marker"></div>'
+					html: '<div id="placeholder_marker' + editor.id + '"></div>'
 				} ]
 			}, {
 				id: 'tab_line',
@@ -567,17 +569,17 @@ html: '<img id="btnAddNewMarker" src="' + pluginUrl + 'images/AddMarker.png" sty
 				{
 					type: 'html',
 					html: '<p>' + editor.lang.googlemaps.msgLineInstruction + '</p>'
-				}, {
-					type: 'text',
-					id: 'txtEncodedPolyline',
-					hidden: 'true'
-				}, {
-					type: 'text',
-					id: 'txtEncodedLevels',
-					hidden: 'true'
+//				}, {
+//					type: 'text',
+//					id: 'txtEncodedPolyline',
+//					hidden: 'true'
+//				}, {
+//					type: 'text',
+//					id: 'txtEncodedLevels',
+//					hidden: 'true'
 				}, {
 					type: 'html',
-					html: '<div id="placeholder_line"></div>'
+					html: '<div id="placeholder_line' + editor.id + '"></div>'
 				} ]
 			} ]
 		};
